@@ -12,8 +12,6 @@
 # License for the specific language governing permissions and limitations under
 # the License.
 
-import six
-
 from pycadf import cadftype
 
 ATTACHMENT_KEYNAME_TYPEURI = "typeURI"
@@ -31,12 +29,10 @@ class Attachment(cadftype.CADFAbstractType):
     # the set of approved attachment types in order to
     # limit and validate them.
     typeURI = cadftype.ValidatorDescriptor(ATTACHMENT_KEYNAME_TYPEURI,
-                                           lambda x: isinstance(
-                                               x, six.string_types))
+                                           lambda x: isinstance(x, str))
     content = cadftype.ValidatorDescriptor(ATTACHMENT_KEYNAME_CONTENT)
     name = cadftype.ValidatorDescriptor(ATTACHMENT_KEYNAME_NAME,
-                                        lambda x: isinstance(x,
-                                                             six.string_types))
+                                        lambda x: isinstance(x, str))
 
     def __init__(self, typeURI=None, content=None, name=None):
         """Create Attachment data type
