@@ -12,8 +12,6 @@
 # License for the specific language governing permissions and limitations under
 # the License.
 
-import six
-
 from pycadf import cadftype
 from pycadf import identifier
 
@@ -35,11 +33,11 @@ class Host(cadftype.CADFAbstractType):
     id = cadftype.ValidatorDescriptor(
         HOST_KEYNAME_ID, lambda x: identifier.is_valid(x))
     address = cadftype.ValidatorDescriptor(
-        HOST_KEYNAME_ADDR, lambda x: isinstance(x, six.string_types))
+        HOST_KEYNAME_ADDR, lambda x: isinstance(x, str))
     agent = cadftype.ValidatorDescriptor(
-        HOST_KEYNAME_AGENT, lambda x: isinstance(x, six.string_types))
+        HOST_KEYNAME_AGENT, lambda x: isinstance(x, str))
     platform = cadftype.ValidatorDescriptor(
-        HOST_KEYNAME_PLATFORM, lambda x: isinstance(x, six.string_types))
+        HOST_KEYNAME_PLATFORM, lambda x: isinstance(x, str))
 
     def __init__(self, id=None, address=None, agent=None,
                  platform=None):
