@@ -13,9 +13,7 @@
 # the License.
 
 import datetime
-
-import pytz
-import six
+import zoneinfo
 
 TIME_FORMAT = "%Y-%m-%dT%H:%M:%S.%f%z"
 
@@ -25,10 +23,11 @@ def get_utc_now(timezone=None):
 
     :param timezone: an optional timezone param to offset time to.
     """
-    utc_datetime = pytz.utc.localize(datetime.datetime.utcnow())
+    utc_datetime = datetime.datetime.now(datetime.timezone.utc)
     if timezone is not None:
         try:
-            utc_datetime = utc_datetime.astimezone(pytz.timezone(timezone))
+            tz = zoneinfo.Zoneinfo(timezone)
+            utc_datetime = utc_datetime.astimezone(tz=tz)
         except Exception:
             utc_datetime.strftime(TIME_FORMAT)
     return utc_datetime.strftime(TIME_FORMAT)
@@ -39,7 +38,7 @@ def get_utc_now(timezone=None):
 def is_valid(value):
     """Validation to ensure timestamp is a string.
     """
-    if not isinstance(value, six.string_types):
+    if not isinstance(value, str):
         raise ValueError('Timestamp should be a String')
 
     return True
